==> ice-3.7.5.tgz: package/src/es5/Glacier2/PermissionsVerifier.js <==
"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

//
// Copyright (c) ZeroC, Inc. All rights reserved.
//
//
// Ice version 3.7.5
//
// <auto-generated>
//
// Generated from file `PermissionsVerifier.ice'
//
// Warning: do not edit this file.
//
// </auto-generated>
//

/* eslint-disable */

/* jshint ignore: start */

/* slice2js browser-bundle-skip */
(function (module, require, exports) {
  /* slice2js browser-bundle-skip-end */

  /* slice2js browser-bundle-skip */
  var _ModuleRegistry = require("../Ice/ModuleRegistry").Ice._ModuleRegistry;

  var Glacier2 = require("../Glacier2/SSLInfo").Glacier2;

  var Ice = _ModuleRegistry.require(module, ["../Ice/Object", "../Ice/Value", "../Ice/ObjectPrx", "../Ice/Operation", "../Ice/Exception", "../Ice/Long", "../Ice/HashMap", "../Ice/HashUtil", "../Ice/ArrayUtil", "../Ice/StreamHelpers"]).Ice;

  var Slice = Ice.Slice;
  /* slice2js browser-bundle-skip-end */

  /**
   * This exception is raised if a client is denied the ability to create
   * a session with the router.
   *
   **/

  Glacier2.PermissionDeniedException = /*#__PURE__*/function (_Ice$UserException) {
    _inherits(_class, _Ice$UserException);

    var _super = _createSuper(_class);

    function _class() {
      var _this;

      var reason = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : "";

      var _cause = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : "";

      _classCallCheck(this, _class);

      _this = _super.call(this, _cause);
      _this.reason = reason;
      return _this;
    }

    _createClass(_class, [{
      key: "_mostDerivedType",
      value: function _mostDerivedType() {
        return Glacier2.PermissionDeniedException;
      }
    }, {
      key: "_writeMemberImpl",
      value: function _writeMemberImpl(ostr) {
        ostr.writeString(this.reason);
      }
    }, {
      key: "_readMemberImpl",
      value: function _readMemberImpl(istr) {
        this.reason = istr.readString();
      }
    }], [{
      key: "_parent",
      get: function get() {
        return Ice.UserException;
      }
    }, {
      key: "_id",
      get: function get() {
        return "::Glacier2::PermissionDeniedException";
      }
    }]);

    return _class;
  }(Ice.UserException);

  Slice.PreservedUserException(Glacier2.PermissionDeniedException);
  var iceC_Glacier2_PermissionsVerifier_ids = ["::Glacier2::PermissionsVerifier", "::Ice::Object"];
  /**
   * The Glacier2 permissions verifier. This is called through the
   * process of establishing a session.
   *
   * @see Router
   *
   **/

  Glacier2.PermissionsVerifier = /*#__PURE__*/function (_Ice$Object) {
    _inherits(_class2, _Ice$Object);

    var _super2 = _createSuper(_class2);

    function _class2() {
      _classCallCheck(this, _class2);

      return _super2.apply(this, arguments);
    }

    return _class2;
  }(Ice.Object);

  Glacier2.PermissionsVerifierPrx = /*#__PURE__*/function (_Ice$ObjectPrx) {
    _inherits(_class3, _Ice$ObjectPrx);

    var _super3 = _createSuper(_class3);

    function _class3() {
      _classCallCheck(this, _class3);

      return _super3.apply(this, arguments);
    }

    return _class3;
  }(Ice.ObjectPrx);

  Slice.defineOperations(Glacier2.PermissionsVerifier, Glacier2.PermissionsVerifierPrx, iceC_Glacier2_PermissionsVerifier_ids, 0, {
    "checkPermissions": [, 2, 1, 2, [1], [[7], [7]], [[7]], [Glacier2.PermissionDeniedException],,]
  });
  var iceC_Glacier2_SSLPermissionsVerifier_ids = ["::Glacier2::SSLPermissionsVerifier", "::Ice::Object"];
  /**
   * The SSL Glacier2 permissions verifier. This is called through the
   * process of establishing a session.
   *
   * @see Router
   *
   **/

  Glacier2.SSLPermissionsVerifier = /*#__PURE__*/function (_Ice$Object2) {
    _inherits(_class4, _Ice$Object2);

    var _super4 = _createSuper(_class4);

    function _class4() {
      _classCallCheck(this, _class4);

      return _super4.apply(this, arguments);
    }

    return _class4;
  }(Ice.Object);

  Glacier2.SSLPermissionsVerifierPrx = /*#__PURE__*/function (_Ice$ObjectPrx2) {
    _inherits(_class5, _Ice$ObjectPrx2);

    var _super5 = _createSuper(_class5);

    function _class5() {
      _classCallCheck(this, _class5);

      return _super5.apply(this, arguments);
    }

    return _class5;
  }(Ice.ObjectPrx);

  Slice.defineOperations(Glacier2.SSLPermissionsVerifier, Glacier2.SSLPermissionsVerifierPrx, iceC_Glacier2_SSLPermissionsVerifier_ids, 0, {
    "authorize": [, 2, 1, 2, [1], [[Glacier2.SSLInfo]], [[7]], [Glacier2.PermissionDeniedException],,]
  });
  /* slice2js browser-bundle-skip */

  exports.Glacier2 = Glacier2;
  /* slice2js browser-bundle-skip-end */

  /* slice2js browser-bundle-skip */
})(typeof global !== "undefined" && typeof global.process !== "undefined" ? module : undefined, typeof global !== "undefined" && typeof global.process !== "undefined" ? require : typeof WorkerGlobalScope !== "undefined" && self instanceof WorkerGlobalScope ? self.Ice._require : window.Ice._require, typeof global !== "undefined" && typeof global.process !== "undefined" ? exports : typeof WorkerGlobalScope !== "undefined" && self instanceof WorkerGlobalScope ? self : window);
/* slice2js browser-bundle-skip-end */

==> ice-3.7.70.tgz: package/src/es5/Glacier2/PermissionsVerifier.js <==
"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

//
// Copyright (c) ZeroC, Inc. All rights reserved.
//
//
// Ice version 3.7.7
//
// <auto-generated>
//
// Generated from file `PermissionsVerifier.ice'
//
// Warning: do not edit this file.
//
// </auto-generated>
//

/* eslint-disable */

/* jshint ignore: start */

/* slice2js browser-bundle-skip */
(function (module, require, exports) {
  /* slice2js browser-bundle-skip-end */

  /* slice2js browser-bundle-skip */
  var _ModuleRegistry = require("../Ice/ModuleRegistry").Ice._ModuleRegistry;

  var Glacier2 = require("../Glacier2/SSLInfo").Glacier2;

  var Ice = _ModuleRegistry.require(module, ["../Ice/Object", "../Ice/Value", "../Ice/ObjectPrx", "../Ice/Operation", "../Ice/Exception", "../Ice/Long", "../Ice/HashMap", "../Ice/HashUtil", "../Ice/ArrayUtil", "../Ice/StreamHelpers"]).Ice;

  var Slice = Ice.Slice;
  /* slice2js browser-bundle-skip-end */

  /**
   * This exception is raised if a client is denied the ability to create
   * a session with the router.
   *
   **/

  Glacier2.PermissionDeniedException = /*#__PURE__*/function (_Ice$UserException) {
    _inherits(_class, _Ice$UserException);

    var _super = _createSuper(_class);

    function _class() {
      var _this;

      var reason = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : "";

      var _cause = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : "";

      _classCallCheck(this, _class);

      _this = _super.call(this, _cause);
      _this.reason = reason;
      return _this;
    }

    _createClass(_class, [{
      key: "_mostDerivedType",
      value: function _mostDerivedType() {
        return Glacier2.PermissionDeniedException;
      }
    }, {
      key: "_writeMemberImpl",
      value: function _writeMemberImpl(ostr) {
        ostr.writeString(this.reason);
      }
    }, {
      key: "_readMemberImpl",
      value: function _readMemberImpl(istr) {
        this.reason = istr.readString();
      }
    }], [{
      key: "_parent",
      get: function get() {
        return Ice.UserException;
      }
    }, {
      key: "_id",
      get: function get() {
        return "::Glacier2::PermissionDeniedException";
      }
    }]);

    return _class;
  }(Ice.UserException);

  Slice.PreservedUserException(Glacier2.PermissionDeniedException);
  var iceC_Glacier2_PermissionsVerifier_ids = ["::Glacier2::PermissionsVerifier", "::Ice::Object"];
  /**
   * The Glacier2 permissions verifier. This is called through the
   * process of establishing a session.
   *
   * @see Router
   *
   **/

  Glacier2.PermissionsVerifier = /*#__PURE__*/function (_Ice$Object) {
    _inherits(_class2, _Ice$Object);

    var _super2 = _createSuper(_class2);

    function _class2() {
      _classCallCheck(this, _class2);

      return _super2.apply(this, arguments);
    }

    return _class2;
  }(Ice.Object);

  Glacier2.PermissionsVerifierPrx = /*#__PURE__*/function (_Ice$ObjectPrx) {
    _inherits(_class3, _Ice$ObjectPrx);

    var _super3 = _createSuper(_class3);

    function _class3() {
      _classCallCheck(this, _class3);

      return _super3.apply(this, arguments);
    }

    return _class3;
  }(Ice.ObjectPrx);

  Slice.defineOperations(Glacier2.PermissionsVerifier, Glacier2.PermissionsVerifierPrx, iceC_Glacier2_PermissionsVerifier_ids, 0, {
    "checkPermissions": [, 2, 1, 2, [1], [[7], [7]], [[7]], [Glacier2.PermissionDeniedException],,]
  });
  var iceC_Glacier2_SSLPermissionsVerifier_ids = ["::Glacier2::SSLPermissionsVerifier", "::Ice::Object"];
  /**
   * The SSL Glacier2 permissions verifier. This is called through the
   * process of establishing a session.
   *
   * @see Router
   *
   **/

  Glacier2.SSLPermissionsVerifier = /*#__PURE__*/function (_Ice$Object2) {
    _inherits(_class4, _Ice$Object2);

    var _super4 = _createSuper(_class4);

    function _class4() {
      _classCallCheck(this, _class4);

      return _super4.apply(this, arguments);
    }

    return _class4;
  }(Ice.Object);

  Glacier2.SSLPermissionsVerifierPrx = /*#__PURE__*/function (_Ice$ObjectPrx2) {
    _inherits(_class5, _Ice$ObjectPrx2);

    var _super5 = _createSuper(_class5);

    function _class5() {
      _classCallCheck(this, _class5);

      return _super5.apply(this, arguments);
    }

    return _class5;
  }(Ice.ObjectPrx);

  Slice.defineOperations(Glacier2.SSLPermissionsVerifier, Glacier2.SSLPermissionsVerifierPrx, iceC_Glacier2_SSLPermissionsVerifier_ids, 0, {
    "authorize": [, 2, 1, 2, [1], [[Glacier2.SSLInfo]], [[7]], [Glacier2.PermissionDeniedException],,]
  });
  /* slice2js browser-bundle-skip */

  exports.Glacier2 = Glacier2;
  /* slice2js browser-bundle-skip-end */

  /* slice2js browser-bundle-skip */
})(typeof global !== "undefined" && typeof global.process !== "undefined" ? module : undefined, typeof global !== "undefined" && typeof global.process !== "undefined" ? require : typeof WorkerGlobalScope !== "undefined" && self instanceof WorkerGlobalScope ? self.Ice._require : window.Ice._require, typeof global !== "undefined" && typeof global.process !== "undefined" ? exports : typeof WorkerGlobalScope !== "undefined" && self instanceof WorkerGlobalScope ? self : window);
/* slice2js browser-bundle-skip-end */
